@@ -48,7 +48,11 @@ def __rec_helper(obj: any, path: [str]):
                     return result
             return None
 
-        current_path_index = int(current_path)
+        try:
+            current_path_index = int(current_path)
+        except Exception as e:
+            print(repr(e))
+            return None
         if current_path_index >= len(obj):
             return None
 
